@@ -15,17 +15,18 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
-
 """
 This module contains Azure Data Explorer hook.
 
-.. spelling::
+.. spelling:word-list::
 
     KustoResponseDataSetV
     kusto
 """
-from typing import Any, Dict, Optional
+from __future__ import annotations
+
+import warnings
+from typing import Any
 
 from azure.kusto.data.exceptions import KustoServiceError
 from azure.kusto.data.request import ClientRequestProperties, KustoClient, KustoConnectionStringBuilder
@@ -33,6 +34,7 @@ from azure.kusto.data.response import KustoResponseDataSetV2
 
 from airflow.exceptions import AirflowException
 from airflow.hooks.base import BaseHook
+from airflow.providers.microsoft.azure.utils import _ensure_prefixes
 
 
 class AzureDataExplorerHook(BaseHook):
@@ -69,82 +71,100 @@ class AzureDataExplorerHook(BaseHook):
         :ref:`Azure Data Explorer connection<howto/connection:adx>`.
     """
 
-    conn_name_attr = 'azure_data_explorer_conn_id'
-    default_conn_name = 'azure_data_explorer_default'
-    conn_type = 'azure_data_explorer'
-    hook_name = 'Azure Data Explorer'
+    conn_name_attr = "azure_data_explorer_conn_id"
+    default_conn_name = "azure_data_explorer_default"
+    conn_type = "azure_data_explorer"
+    hook_name = "Azure Data Explorer"
 
     @staticmethod
-    def get_connection_form_widgets() -> Dict[str, Any]:
-        """Returns connection widgets to add to connection form"""
+    def get_connection_form_widgets() -> dict[str, Any]:
+        """Returns connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3PasswordFieldWidget, BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import PasswordField, StringField
 
         return {
-            "extra__azure_data_explorer__tenant": StringField(
-                lazy_gettext('Tenant ID'), widget=BS3TextFieldWidget()
+            "tenant": StringField(lazy_gettext("Tenant ID"), widget=BS3TextFieldWidget()),
+            "auth_method": StringField(lazy_gettext("Authentication Method"), widget=BS3TextFieldWidget()),
+            "certificate": PasswordField(
+                lazy_gettext("Application PEM Certificate"), widget=BS3PasswordFieldWidget()
             ),
-            "extra__azure_data_explorer__auth_method": StringField(
-                lazy_gettext('Authentication Method'), widget=BS3TextFieldWidget()
-            ),
-            "extra__azure_data_explorer__certificate": PasswordField(
-                lazy_gettext('Application PEM Certificate'), widget=BS3PasswordFieldWidget()
-            ),
-            "extra__azure_data_explorer__thumbprint": PasswordField(
-                lazy_gettext('Application Certificate Thumbprint'), widget=BS3PasswordFieldWidget()
+            "thumbprint": PasswordField(
+                lazy_gettext("Application Certificate Thumbprint"), widget=BS3PasswordFieldWidget()
             ),
         }
 
     @staticmethod
-    def get_ui_field_behaviour() -> Dict[str, Any]:
-        """Returns custom field behaviour"""
+    @_ensure_prefixes(conn_type="azure_data_explorer")
+    def get_ui_field_behaviour() -> dict[str, Any]:
+        """Returns custom field behaviour."""
         return {
-            "hidden_fields": ['schema', 'port', 'extra'],
+            "hidden_fields": ["schema", "port", "extra"],
             "relabeling": {
-                'login': 'Username',
-                'host': 'Data Explorer Cluster URL',
+                "login": "Username",
+                "host": "Data Explorer Cluster URL",
             },
             "placeholders": {
-                'login': 'Varies with authentication method',
-                'password': 'Varies with authentication method',
-                'extra__azure_data_explorer__auth_method': 'AAD_APP/AAD_APP_CERT/AAD_CREDS/AAD_DEVICE',
-                'extra__azure_data_explorer__tenant': 'Used with AAD_APP/AAD_APP_CERT/AAD_CREDS',
-                'extra__azure_data_explorer__certificate': 'Used with AAD_APP_CERT',
-                'extra__azure_data_explorer__thumbprint': 'Used with AAD_APP_CERT',
+                "login": "Varies with authentication method",
+                "password": "Varies with authentication method",
+                "auth_method": "AAD_APP/AAD_APP_CERT/AAD_CREDS/AAD_DEVICE",
+                "tenant": "Used with AAD_APP/AAD_APP_CERT/AAD_CREDS",
+                "certificate": "Used with AAD_APP_CERT",
+                "thumbprint": "Used with AAD_APP_CERT",
             },
         }
 
     def __init__(self, azure_data_explorer_conn_id: str = default_conn_name) -> None:
         super().__init__()
         self.conn_id = azure_data_explorer_conn_id
-        self.connection = self.get_conn()
+        self.connection = self.get_conn()  # todo: make this a property, or just delete
 
     def get_conn(self) -> KustoClient:
         """Return a KustoClient object."""
         conn = self.get_connection(self.conn_id)
+        extras = conn.extra_dejson
         cluster = conn.host
         if not cluster:
-            raise AirflowException('Host connection option is required')
+            raise AirflowException("Host connection option is required")
+
+        def warn_if_collison(key, backcompat_key):
+            if backcompat_key in extras:
+                warnings.warn(
+                    f"Conflicting params `{key}` and `{backcompat_key}` found in extras for conn "
+                    f"{self.conn_id}. Using value for `{key}`.  Please ensure this is the correct value "
+                    f"and remove the backcompat key `{backcompat_key}`."
+                )
 
         def get_required_param(name: str) -> str:
-            """Extract required parameter value from connection, raise exception if not found"""
-            value = conn.extra_dejson.get(name)
+            """
+            Extract required parameter value from connection, raise exception if not found.
+
+            Warns if both ``foo`` and ``extra__azure_data_explorer__foo`` found in conn extra.
+
+            Prefers unprefixed field.
+            """
+            backcompat_prefix = "extra__azure_data_explorer__"
+            backcompat_key = f"{backcompat_prefix}{name}"
+            value = extras.get(name)
+            if value:
+                warn_if_collison(name, backcompat_key)
             if not value:
-                raise AirflowException(f'Required connection parameter is missing: `{name}`')
+                value = extras.get(backcompat_key)
+            if not value:
+                raise AirflowException(f"Required connection parameter is missing: `{name}`")
             return value
 
-        auth_method = get_required_param('extra__azure_data_explorer__auth_method')
+        auth_method = get_required_param("auth_method")
 
-        if auth_method == 'AAD_APP':
-            tenant = get_required_param('extra__azure_data_explorer__tenant')
+        if auth_method == "AAD_APP":
+            tenant = get_required_param("tenant")
             kcsb = KustoConnectionStringBuilder.with_aad_application_key_authentication(
                 cluster, conn.login, conn.password, tenant
             )
-        elif auth_method == 'AAD_APP_CERT':
-            certificate = get_required_param('extra__azure_data_explorer__certificate')
-            thumbprint = get_required_param('extra__azure_data_explorer__thumbprint')
-            tenant = get_required_param('extra__azure_data_explorer__tenant')
+        elif auth_method == "AAD_APP_CERT":
+            certificate = get_required_param("certificate")
+            thumbprint = get_required_param("thumbprint")
+            tenant = get_required_param("tenant")
             kcsb = KustoConnectionStringBuilder.with_aad_application_certificate_authentication(
                 cluster,
                 conn.login,
@@ -152,19 +172,19 @@ class AzureDataExplorerHook(BaseHook):
                 thumbprint,
                 tenant,
             )
-        elif auth_method == 'AAD_CREDS':
-            tenant = get_required_param('extra__azure_data_explorer__tenant')
+        elif auth_method == "AAD_CREDS":
+            tenant = get_required_param("tenant")
             kcsb = KustoConnectionStringBuilder.with_aad_user_password_authentication(
                 cluster, conn.login, conn.password, tenant
             )
-        elif auth_method == 'AAD_DEVICE':
+        elif auth_method == "AAD_DEVICE":
             kcsb = KustoConnectionStringBuilder.with_aad_device_authentication(cluster)
         else:
-            raise AirflowException(f'Unknown authentication method: {auth_method}')
+            raise AirflowException(f"Unknown authentication method: {auth_method}")
 
         return KustoClient(kcsb)
 
-    def run_query(self, query: str, database: str, options: Optional[Dict] = None) -> KustoResponseDataSetV2:
+    def run_query(self, query: str, database: str, options: dict | None = None) -> KustoResponseDataSetV2:
         """
         Run KQL query using provided configuration, and return
         `azure.kusto.data.response.KustoResponseDataSet` instance.
@@ -183,4 +203,4 @@ class AzureDataExplorerHook(BaseHook):
         try:
             return self.connection.execute(database, query, properties=properties)
         except KustoServiceError as error:
-            raise AirflowException(f'Error running Kusto query: {error}')
+            raise AirflowException(f"Error running Kusto query: {error}")
