@@ -22,6 +22,7 @@ from typing import Any
 from azure.mgmt.containerinstance.models import AzureFileVolume, Volume
 
 from airflow.hooks.base import BaseHook
+from airflow.providers.microsoft.azure.utils import _ensure_prefixes, get_field
 
 
 class AzureContainerVolumeHook(BaseHook):
@@ -34,50 +35,59 @@ class AzureContainerVolumeHook(BaseHook):
     """
 
     conn_name_attr = "azure_container_volume_conn_id"
-    default_conn_name = 'azure_container_volume_default'
-    conn_type = 'azure_container_volume'
-    hook_name = 'Azure Container Volume'
+    default_conn_name = "azure_container_volume_default"
+    conn_type = "azure_container_volume"
+    hook_name = "Azure Container Volume"
 
-    def __init__(self, azure_container_volume_conn_id: str = 'azure_container_volume_default') -> None:
+    def __init__(self, azure_container_volume_conn_id: str = "azure_container_volume_default") -> None:
         super().__init__()
         self.conn_id = azure_container_volume_conn_id
 
+    def _get_field(self, extras, name):
+        return get_field(
+            conn_id=self.conn_id,
+            conn_type=self.conn_type,
+            extras=extras,
+            field_name=name,
+        )
+
     @staticmethod
     def get_connection_form_widgets() -> dict[str, Any]:
-        """Returns connection widgets to add to connection form"""
+        """Returns connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3PasswordFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import PasswordField
 
         return {
-            "extra__azure_container_volume__connection_string": PasswordField(
-                lazy_gettext('Blob Storage Connection String (optional)'), widget=BS3PasswordFieldWidget()
+            "connection_string": PasswordField(
+                lazy_gettext("Blob Storage Connection String (optional)"), widget=BS3PasswordFieldWidget()
             ),
         }
 
     @staticmethod
+    @_ensure_prefixes(conn_type="azure_container_volume")
     def get_ui_field_behaviour() -> dict[str, Any]:
-        """Returns custom field behaviour"""
+        """Returns custom field behaviour."""
         return {
-            "hidden_fields": ['schema', 'port', 'host', "extra"],
+            "hidden_fields": ["schema", "port", "host", "extra"],
             "relabeling": {
-                'login': 'Azure Client ID',
-                'password': 'Azure Secret',
+                "login": "Azure Client ID",
+                "password": "Azure Secret",
             },
             "placeholders": {
-                'login': 'client_id (token credentials auth)',
-                'password': 'secret (token credentials auth)',
-                'extra__azure_container_volume__connection_string': 'connection string auth',
+                "login": "client_id (token credentials auth)",
+                "password": "secret (token credentials auth)",
+                "connection_string": "connection string auth",
             },
         }
 
     def get_storagekey(self) -> str:
-        """Get Azure File Volume storage key"""
+        """Get Azure File Volume storage key."""
         conn = self.get_connection(self.conn_id)
-        service_options = conn.extra_dejson
-
-        if 'extra__azure_container_volume__connection_string' in service_options:
-            for keyvalue in service_options['extra__azure_container_volume__connection_string'].split(";"):
+        extras = conn.extra_dejson
+        connection_string = self._get_field(extras, "connection_string")
+        if connection_string:
+            for keyvalue in connection_string.split(";"):
                 key, value = keyvalue.split("=", 1)
                 if key == "AccountKey":
                     return value
@@ -86,7 +96,7 @@ class AzureContainerVolumeHook(BaseHook):
     def get_file_volume(
         self, mount_name: str, share_name: str, storage_account_name: str, read_only: bool = False
     ) -> Volume:
-        """Get Azure File Volume"""
+        """Get Azure File Volume."""
         return Volume(
             name=mount_name,
             azure_file=AzureFileVolume(
