@@ -34,6 +34,7 @@ from azure.cosmos.exceptions import CosmosHttpResponseError
 
 from airflow.exceptions import AirflowBadRequest
 from airflow.hooks.base import BaseHook
+from airflow.providers.microsoft.azure.utils import _ensure_prefixes, get_field
 
 
 class AzureCosmosDBHook(BaseHook):
@@ -48,41 +49,42 @@ class AzureCosmosDBHook(BaseHook):
         :ref:`Azure CosmosDB connection<howto/connection:azure_cosmos>`.
     """
 
-    conn_name_attr = 'azure_cosmos_conn_id'
-    default_conn_name = 'azure_cosmos_default'
-    conn_type = 'azure_cosmos'
-    hook_name = 'Azure CosmosDB'
+    conn_name_attr = "azure_cosmos_conn_id"
+    default_conn_name = "azure_cosmos_default"
+    conn_type = "azure_cosmos"
+    hook_name = "Azure CosmosDB"
 
     @staticmethod
     def get_connection_form_widgets() -> dict[str, Any]:
-        """Returns connection widgets to add to connection form"""
+        """Returns connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import StringField
 
         return {
-            "extra__azure_cosmos__database_name": StringField(
-                lazy_gettext('Cosmos Database Name (optional)'), widget=BS3TextFieldWidget()
+            "database_name": StringField(
+                lazy_gettext("Cosmos Database Name (optional)"), widget=BS3TextFieldWidget()
             ),
-            "extra__azure_cosmos__collection_name": StringField(
-                lazy_gettext('Cosmos Collection Name (optional)'), widget=BS3TextFieldWidget()
+            "collection_name": StringField(
+                lazy_gettext("Cosmos Collection Name (optional)"), widget=BS3TextFieldWidget()
             ),
         }
 
     @staticmethod
+    @_ensure_prefixes(conn_type="azure_cosmos")  # todo: remove when min airflow version >= 2.5
     def get_ui_field_behaviour() -> dict[str, Any]:
-        """Returns custom field behaviour"""
+        """Returns custom field behaviour."""
         return {
-            "hidden_fields": ['schema', 'port', 'host', 'extra'],
+            "hidden_fields": ["schema", "port", "host", "extra"],
             "relabeling": {
-                'login': 'Cosmos Endpoint URI',
-                'password': 'Cosmos Master Key Token',
+                "login": "Cosmos Endpoint URI",
+                "password": "Cosmos Master Key Token",
             },
             "placeholders": {
-                'login': 'endpoint uri',
-                'password': 'master key',
-                'extra__azure_cosmos__database_name': 'database name',
-                'extra__azure_cosmos__collection_name': 'collection name',
+                "login": "endpoint uri",
+                "password": "master key",
+                "database_name": "database name",
+                "collection_name": "collection name",
             },
         }
 
@@ -94,6 +96,14 @@ class AzureCosmosDBHook(BaseHook):
         self.default_database_name = None
         self.default_collection_name = None
 
+    def _get_field(self, extras, name):
+        return get_field(
+            conn_id=self.conn_id,
+            conn_type=self.conn_type,
+            extras=extras,
+            field_name=name,
+        )
+
     def get_conn(self) -> CosmosClient:
         """Return a cosmos db client."""
         if not self._conn:
@@ -102,15 +112,11 @@ class AzureCosmosDBHook(BaseHook):
             endpoint_uri = conn.login
             master_key = conn.password
 
-            self.default_database_name = extras.get('database_name') or extras.get(
-                'extra__azure_cosmos__database_name'
-            )
-            self.default_collection_name = extras.get('collection_name') or extras.get(
-                'extra__azure_cosmos__collection_name'
-            )
+            self.default_database_name = self._get_field(extras, "database_name")
+            self.default_collection_name = self._get_field(extras, "collection_name")
 
             # Initialize the Python Azure Cosmos DB client
-            self._conn = CosmosClient(endpoint_uri, {'masterKey': master_key})
+            self._conn = CosmosClient(endpoint_uri, {"masterKey": master_key})
         return self._conn
 
     def __get_database_name(self, database_name: str | None = None) -> str:
@@ -243,11 +249,11 @@ class AzureCosmosDBHook(BaseHook):
             raise AirflowBadRequest("You cannot insert a None document")
 
         # Add document id if isn't found
-        if 'id' in document:
-            if document['id'] is None:
-                document['id'] = document_id
+        if "id" in document:
+            if document["id"] is None:
+                document["id"] = document_id
         else:
-            document['id'] = document_id
+            document["id"] = document_id
 
         created_document = (
             self.get_conn()
@@ -351,15 +357,15 @@ class AzureCosmosDBHook(BaseHook):
 
 
 def get_database_link(database_id: str) -> str:
-    """Get Azure CosmosDB database link"""
+    """Get Azure CosmosDB database link."""
     return "dbs/" + database_id
 
 
 def get_collection_link(database_id: str, collection_id: str) -> str:
-    """Get Azure CosmosDB collection link"""
+    """Get Azure CosmosDB collection link."""
     return get_database_link(database_id) + "/colls/" + collection_id
 
 
 def get_document_link(database_id: str, collection_id: str, document_id: str) -> str:
-    """Get Azure CosmosDB document link"""
+    """Get Azure CosmosDB document link."""
     return get_collection_link(database_id, collection_id) + "/docs/" + document_id
