@@ -37,21 +37,20 @@ from airflow.providers.microsoft.azure.utils import _ensure_prefixes, get_field
 
 
 class AzureDataLakeHook(BaseHook):
-    """
-    This module contains integration with Azure Data Lake.
+    """Integration with Azure Data Lake.
 
-    AzureDataLakeHook communicates via a REST API compatible with WebHDFS. Make sure that a
-    Airflow connection of type `azure_data_lake` exists. Authorization can be done by supplying a
-    login (=Client ID), password (=Client Secret) and extra fields tenant (Tenant) and account_name
-    (Account Name)(see connection `azure_data_lake_default` for an example).
+    AzureDataLakeHook communicates via a REST API compatible with WebHDFS. Make
+    sure that a Airflow connection of type ``azure_data_lake`` exists.
+    Authorization can be done by supplying a *login* (=Client ID), *password*
+    (=Client Secret), and extra fields *tenant* (Tenant) and *account_name*
+    (Account Name). See connection ``azure_data_lake_default`` for an example.
 
-    Interacts with Azure Data Lake.
-
-    Client ID and client secret should be in user and password parameters.
+    Client ID and secret should be in user and password parameters.
     Tenant and account name should be extra field as
-    {"tenant": "<TENANT>", "account_name": "ACCOUNT_NAME"}.
+    ``{"tenant": "<TENANT>", "account_name": "ACCOUNT_NAME"}``.
 
-    :param azure_data_lake_conn_id: Reference to the :ref:`Azure Data Lake connection<howto/connection:adl>`.
+    :param azure_data_lake_conn_id: Reference to
+        :ref:`Azure Data Lake connection<howto/connection:adl>`.
     """
 
     conn_name_attr = "azure_data_lake_conn_id"
@@ -61,7 +60,7 @@ class AzureDataLakeHook(BaseHook):
 
     @staticmethod
     def get_connection_form_widgets() -> dict[str, Any]:
-        """Returns connection widgets to add to connection form"""
+        """Returns connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import StringField
@@ -76,7 +75,7 @@ class AzureDataLakeHook(BaseHook):
     @staticmethod
     @_ensure_prefixes(conn_type="azure_data_lake")
     def get_ui_field_behaviour() -> dict[str, Any]:
-        """Returns custom field behaviour"""
+        """Returns custom field behaviour."""
         return {
             "hidden_fields": ["schema", "port", "host", "extra"],
             "relabeling": {
@@ -118,8 +117,7 @@ class AzureDataLakeHook(BaseHook):
         return self._conn
 
     def check_for_file(self, file_path: str) -> bool:
-        """
-        Check if a file exists on Azure Data Lake.
+        """Check if a file exists on Azure Data Lake.
 
         :param file_path: Path and name of the file.
         :return: True if the file exists, False otherwise.
@@ -140,8 +138,7 @@ class AzureDataLakeHook(BaseHook):
         blocksize: int = 4194304,
         **kwargs,
     ) -> None:
-        """
-        Upload a file to Azure Data Lake.
+        """Upload a file to Azure Data Lake.
 
         :param local_path: local path. Can be single file, directory (in which case,
             upload recursively) or glob pattern. Recursive glob patterns using `**`
@@ -181,8 +178,7 @@ class AzureDataLakeHook(BaseHook):
         blocksize: int = 4194304,
         **kwargs,
     ) -> None:
-        """
-        Download a file from Azure Blob Storage.
+        """Download a file from Azure Blob Storage.
 
         :param local_path: local path. If downloading a single file, will write to this
             specific file, unless it is an existing directory, in which case a file is
@@ -214,8 +210,7 @@ class AzureDataLakeHook(BaseHook):
         )
 
     def list(self, path: str) -> list:
-        """
-        List files in Azure Data Lake Storage
+        """List files in Azure Data Lake Storage.
 
         :param path: full path/globstring to use to list files in ADLS
         """
@@ -225,8 +220,7 @@ class AzureDataLakeHook(BaseHook):
             return self.get_conn().walk(path)
 
     def remove(self, path: str, recursive: bool = False, ignore_not_found: bool = True) -> None:
-        """
-        Remove files in Azure Data Lake Storage
+        """Remove files in Azure Data Lake Storage.
 
         :param path: A directory or file to remove in ADLS
         :param recursive: Whether to loop into directories in the location and remove the files
@@ -242,13 +236,14 @@ class AzureDataLakeHook(BaseHook):
 
 
 class AzureDataLakeStorageV2Hook(BaseHook):
-    """
-    This Hook interacts with ADLS gen2 storage account it mainly helps to create and manage
-    directories and files in storage accounts that have a hierarchical namespace. Using Adls_v2 connection
-    details create DataLakeServiceClient object
+    """Interact with a ADLS gen2 storage account.
 
-    Due to Wasb is marked as legacy and and retirement of the (ADLS1) it would be nice to
-    implement ADLS gen2 hook for interacting with the storage account.
+    It mainly helps to create and manage directories and files in storage
+    accounts that have a hierarchical namespace. Using Adls_v2 connection
+    details create DataLakeServiceClient object.
+
+    Due to Wasb is marked as legacy and and retirement of the (ADLS1), it would
+    be nice to implement ADLS gen2 hook for interacting with the storage account.
 
     .. seealso::
         https://learn.microsoft.com/en-us/azure/storage/blobs/data-lake-storage-directory-file-acl-python
@@ -264,37 +259,37 @@ class AzureDataLakeStorageV2Hook(BaseHook):
 
     @staticmethod
     def get_connection_form_widgets() -> dict[str, Any]:
-        """Returns connection widgets to add to connection form"""
+        """Returns connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3PasswordFieldWidget, BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import PasswordField, StringField
 
         return {
             "connection_string": PasswordField(
-                lazy_gettext("ADLS gen2 Connection String (optional)"), widget=BS3PasswordFieldWidget()
+                lazy_gettext("ADLS Gen2 Connection String (optional)"), widget=BS3PasswordFieldWidget()
             ),
             "tenant_id": StringField(
-                lazy_gettext("Tenant Id (Active Directory Auth)"), widget=BS3TextFieldWidget()
+                lazy_gettext("Tenant ID (Active Directory)"), widget=BS3TextFieldWidget()
             ),
         }
 
     @staticmethod
     def get_ui_field_behaviour() -> dict[str, Any]:
-        """Returns custom field behaviour"""
+        """Returns custom field behaviour."""
         return {
             "hidden_fields": ["schema", "port"],
             "relabeling": {
-                "login": "ADLS gen2 Storage Login (optional)",
-                "password": "ADLS gen2 Storage Key (optional)",
-                "host": "Account Name (Active Directory Auth)",
+                "login": "Client ID (Active Directory)",
+                "password": "ADLS Gen2 Key / Client Secret (Active Directory)",
+                "host": "ADLS Gen2 Account Name",
             },
             "placeholders": {
                 "extra": "additional options for use with FileService and AzureFileVolume",
-                "login": "account name",
-                "password": "secret",
-                "host": "account url",
-                "connection_string": "connection string auth",
-                "tenant_id": "tenant",
+                "login": "client id",
+                "password": "key / secret",
+                "host": "storage account name",
+                "connection_string": "connection string (overrides auth)",
+                "tenant_id": "tenant id",
             },
         }
 
@@ -321,13 +316,13 @@ class AzureDataLakeStorageV2Hook(BaseHook):
             app_secret = conn.password
             token_credential = ClientSecretCredential(tenant, app_id, app_secret)
             return DataLakeServiceClient(
-                account_url=f"https://{conn.login}.dfs.core.windows.net", credential=token_credential, **extra
+                account_url=f"https://{conn.host}.dfs.core.windows.net", credential=token_credential, **extra
             )
+
+        # otherwise, use key auth
         credential = conn.password
         return DataLakeServiceClient(
-            account_url=f"https://{conn.login}.dfs.core.windows.net",
-            credential=credential,
-            **extra,
+            account_url=f"https://{conn.host}.dfs.core.windows.net", credential=credential, **extra
         )
 
     def _get_field(self, extra_dict, field_name):
@@ -342,9 +337,9 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         return extra_dict.get(f"{prefix}{field_name}") or None
 
     def create_file_system(self, file_system_name: str) -> None:
-        """
-        A container acts as a file system for your files. Creates a new file system under
-        the specified account.
+        """Create a new file system under the specified account.
+
+        A container acts as a file system for your files.
 
         If the file system with the same name already exists, a ResourceExistsError will
         be raised. This method returns a client with which to interact with the newly
@@ -360,8 +355,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
             raise
 
     def get_file_system(self, file_system: FileSystemProperties | str) -> FileSystemClient:
-        """
-        Get a client to interact with the specified file system
+        """Get a client to interact with the specified file system.
 
         :param file_system: This can either be the name of the file system
             or an instance of FileSystemProperties.
@@ -379,8 +373,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
     def create_directory(
         self, file_system_name: FileSystemProperties | str, directory_name: str, **kwargs
     ) -> DataLakeDirectoryClient:
-        """
-        Create a directory under the specified file system.
+        """Create a directory under the specified file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param directory_name: Name of the directory which needs to be created in the file system.
@@ -393,8 +386,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         file_system_name: FileSystemProperties | str,
         directory_name: DirectoryProperties | str,
     ) -> DataLakeDirectoryClient:
-        """
-        Get the specific directory under the specified file system.
+        """Get the specific directory under the specified file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param directory_name: Name of the directory or instance of DirectoryProperties which needs to be
@@ -413,8 +405,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
             raise
 
     def create_file(self, file_system_name: FileSystemProperties | str, file_name: str) -> DataLakeFileClient:
-        """
-        Creates a file under the file system
+        """Create a file under the file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param file_name: Name of the file which needs to be created in the file system.
@@ -430,8 +421,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         overwrite: bool = False,
         **kwargs: Any,
     ) -> None:
-        """
-        Create a file with data in the file system
+        """Create a file with data in the file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param file_name: Name of the file to be created with name.
@@ -451,9 +441,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         overwrite: bool = False,
         **kwargs: Any,
     ) -> None:
-        """
-        Create a new file and return the file client to be interacted with and then
-        upload data to a file
+        """Upload data to a file.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param directory_name: Name of the directory.
@@ -469,8 +457,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
     def list_files_directory(
         self, file_system_name: FileSystemProperties | str, directory_name: str
     ) -> list[str]:
-        """
-        Get the list of files or directories under the specified file system
+        """List files or directories under the specified file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param directory_name: Name of the directory.
@@ -484,8 +471,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
     def list_file_system(
         self, prefix: str | None = None, include_metadata: bool = False, **kwargs: Any
     ) -> list[str]:
-        """
-        Get the list the file systems under the specified account.
+        """List file systems under the specified account.
 
         :param prefix:
             Filters the results to return only file systems whose names
@@ -502,8 +488,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         return file_system_list
 
     def delete_file_system(self, file_system_name: FileSystemProperties | str) -> None:
-        """
-        Deletes the file system
+        """Delete the file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         """
@@ -517,8 +502,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
             raise
 
     def delete_directory(self, file_system_name: FileSystemProperties | str, directory_name: str) -> None:
-        """
-        Deletes specified directory in file system
+        """Delete the specified directory in a file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param directory_name: Name of the directory.
