@@ -29,8 +29,7 @@ if TYPE_CHECKING:
 
 
 class AzureServiceBusCreateQueueOperator(BaseOperator):
-    """
-    Creates a Azure Service Bus queue under a Service Bus Namespace by using ServiceBusAdministrationClient
+    """Create a Azure Service Bus queue under a Service Bus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -57,7 +56,7 @@ class AzureServiceBusCreateQueueOperator(BaseOperator):
         max_delivery_count: int = 10,
         dead_lettering_on_message_expiration: bool = True,
         enable_batched_operations: bool = True,
-        azure_service_bus_conn_id: str = 'azure_service_bus_default',
+        azure_service_bus_conn_id: str = "azure_service_bus_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -68,7 +67,7 @@ class AzureServiceBusCreateQueueOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Creates Queue in Azure Service Bus namespace, by connecting to Service Bus Admin client in hook"""
+        """Creates Queue in Azure Service Bus namespace, by connecting to Service Bus Admin client in hook."""
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
         # create queue with name
@@ -82,8 +81,7 @@ class AzureServiceBusCreateQueueOperator(BaseOperator):
 
 
 class AzureServiceBusSendMessageOperator(BaseOperator):
-    """
-    Send Message or batch message to the Service Bus queue
+    """Send Message or batch message to the Service Bus queue.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -106,7 +104,7 @@ class AzureServiceBusSendMessageOperator(BaseOperator):
         queue_name: str,
         message: str | list[str],
         batch: bool = False,
-        azure_service_bus_conn_id: str = 'azure_service_bus_default',
+        azure_service_bus_conn_id: str = "azure_service_bus_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -116,10 +114,7 @@ class AzureServiceBusSendMessageOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """
-        Sends Message to the specific queue in Service Bus namespace, by
-        connecting to Service Bus  client
-        """
+        """Sends Message to the specific queue in Service Bus namespace."""
         # Create the hook
         hook = MessageHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
@@ -128,8 +123,7 @@ class AzureServiceBusSendMessageOperator(BaseOperator):
 
 
 class AzureServiceBusReceiveMessageOperator(BaseOperator):
-    """
-    Receive a batch of messages at once in a specified Queue name
+    """Receive a batch of messages at once in a specified Queue name.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -149,7 +143,7 @@ class AzureServiceBusReceiveMessageOperator(BaseOperator):
         self,
         *,
         queue_name: str,
-        azure_service_bus_conn_id: str = 'azure_service_bus_default',
+        azure_service_bus_conn_id: str = "azure_service_bus_default",
         max_message_count: int = 10,
         max_wait_time: float = 5,
         **kwargs,
@@ -163,7 +157,7 @@ class AzureServiceBusReceiveMessageOperator(BaseOperator):
     def execute(self, context: Context) -> None:
         """
         Receive Message in specific queue in Service Bus namespace,
-        by connecting to Service Bus client
+        by connecting to Service Bus client.
         """
         # Create the hook
         hook = MessageHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
@@ -175,8 +169,7 @@ class AzureServiceBusReceiveMessageOperator(BaseOperator):
 
 
 class AzureServiceBusDeleteQueueOperator(BaseOperator):
-    """
-    Deletes the Queue in the Azure Service Bus namespace
+    """Delete the Queue in the Azure Service Bus namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -194,7 +187,7 @@ class AzureServiceBusDeleteQueueOperator(BaseOperator):
         self,
         *,
         queue_name: str,
-        azure_service_bus_conn_id: str = 'azure_service_bus_default',
+        azure_service_bus_conn_id: str = "azure_service_bus_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -202,7 +195,7 @@ class AzureServiceBusDeleteQueueOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Delete Queue in Service Bus namespace, by connecting to Service Bus Admin client"""
+        """Delete Queue in Service Bus namespace, by connecting to Service Bus Admin client."""
         # Create the hook
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
@@ -211,8 +204,7 @@ class AzureServiceBusDeleteQueueOperator(BaseOperator):
 
 
 class AzureServiceBusTopicCreateOperator(BaseOperator):
-    """
-    Create an Azure Service Bus Topic under a Service Bus Namespace by using ServiceBusAdministrationClient
+    """Create an Azure Service Bus Topic under a Service Bus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -260,7 +252,7 @@ class AzureServiceBusTopicCreateOperator(BaseOperator):
         self,
         *,
         topic_name: str,
-        azure_service_bus_conn_id: str = 'azure_service_bus_default',
+        azure_service_bus_conn_id: str = "azure_service_bus_default",
         default_message_time_to_live: datetime.timedelta | str | None = None,
         max_size_in_megabytes: int | None = None,
         requires_duplicate_detection: bool | None = None,
@@ -296,7 +288,7 @@ class AzureServiceBusTopicCreateOperator(BaseOperator):
         self.max_message_size_in_kilobytes = max_message_size_in_kilobytes
 
     def execute(self, context: Context) -> str:
-        """Creates Topic in Service Bus namespace, by connecting to Service Bus Admin client"""
+        """Creates Topic in Service Bus namespace, by connecting to Service Bus Admin client."""
         if self.topic_name is None:
             raise TypeError("Topic name cannot be None.")
 
@@ -330,9 +322,7 @@ class AzureServiceBusTopicCreateOperator(BaseOperator):
 
 
 class AzureServiceBusSubscriptionCreateOperator(BaseOperator):
-    """
-    Create an Azure Service Bus Topic Subscription under a Service Bus Namespace
-    by using ServiceBusAdministrationClient
+    """Create an Azure Service Bus Topic Subscription under a Service Bus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -378,7 +368,7 @@ class AzureServiceBusSubscriptionCreateOperator(BaseOperator):
         *,
         topic_name: str,
         subscription_name: str,
-        azure_service_bus_conn_id: str = 'azure_service_bus_default',
+        azure_service_bus_conn_id: str = "azure_service_bus_default",
         lock_duration: datetime.timedelta | str | None = None,
         requires_session: bool | None = None,
         default_message_time_to_live: datetime.timedelta | str | None = None,
@@ -409,7 +399,7 @@ class AzureServiceBusSubscriptionCreateOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Creates Subscription in Service Bus namespace, by connecting to Service Bus Admin client"""
+        """Creates Subscription in Service Bus namespace, by connecting to Service Bus Admin client."""
         if self.subscription_name is None:
             raise TypeError("Subscription name cannot be None.")
         if self.topic_name is None:
@@ -438,9 +428,7 @@ class AzureServiceBusSubscriptionCreateOperator(BaseOperator):
 
 
 class AzureServiceBusUpdateSubscriptionOperator(BaseOperator):
-    """
-    Update an Azure ServiceBus Topic Subscription under a ServiceBus Namespace
-    by using ServiceBusAdministrationClient
+    """Update an Azure ServiceBus Topic Subscription under a ServiceBus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -469,7 +457,7 @@ class AzureServiceBusUpdateSubscriptionOperator(BaseOperator):
         max_delivery_count: int | None = None,
         dead_lettering_on_message_expiration: bool | None = None,
         enable_batched_operations: bool | None = None,
-        azure_service_bus_conn_id: str = 'azure_service_bus_default',
+        azure_service_bus_conn_id: str = "azure_service_bus_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -481,7 +469,7 @@ class AzureServiceBusUpdateSubscriptionOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Updates Subscription properties, by connecting to Service Bus Admin client"""
+        """Updates Subscription properties, by connecting to Service Bus Admin client."""
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
         with hook.get_conn() as service_mgmt_conn:
@@ -499,8 +487,7 @@ class AzureServiceBusUpdateSubscriptionOperator(BaseOperator):
 
 
 class ASBReceiveSubscriptionMessageOperator(BaseOperator):
-    """
-    Receive a Batch messages from a Service Bus Subscription under specific Topic.
+    """Receive a Batch messages from a Service Bus Subscription under specific Topic.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -529,7 +516,7 @@ class ASBReceiveSubscriptionMessageOperator(BaseOperator):
         subscription_name: str,
         max_message_count: int | None = 1,
         max_wait_time: float | None = 5,
-        azure_service_bus_conn_id: str = 'azure_service_bus_default',
+        azure_service_bus_conn_id: str = "azure_service_bus_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -542,7 +529,7 @@ class ASBReceiveSubscriptionMessageOperator(BaseOperator):
     def execute(self, context: Context) -> None:
         """
         Receive Message in specific queue in Service Bus namespace,
-        by connecting to Service Bus client
+        by connecting to Service Bus client.
         """
         # Create the hook
         hook = MessageHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
@@ -554,8 +541,7 @@ class ASBReceiveSubscriptionMessageOperator(BaseOperator):
 
 
 class AzureServiceBusSubscriptionDeleteOperator(BaseOperator):
-    """
-    Deletes the topic subscription in the Azure ServiceBus namespace
+    """Delete the topic subscription in the Azure ServiceBus namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -575,7 +561,7 @@ class AzureServiceBusSubscriptionDeleteOperator(BaseOperator):
         *,
         topic_name: str,
         subscription_name: str,
-        azure_service_bus_conn_id: str = 'azure_service_bus_default',
+        azure_service_bus_conn_id: str = "azure_service_bus_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -584,7 +570,7 @@ class AzureServiceBusSubscriptionDeleteOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Delete topic subscription in Service Bus namespace, by connecting to Service Bus Admin client"""
+        """Delete topic subscription in Service Bus namespace, by connecting to Service Bus Admin client."""
         # Create the hook
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
@@ -593,8 +579,7 @@ class AzureServiceBusSubscriptionDeleteOperator(BaseOperator):
 
 
 class AzureServiceBusTopicDeleteOperator(BaseOperator):
-    """
-    Deletes the topic in the Azure Service Bus namespace
+    """Delete the topic in the Azure Service Bus namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -612,7 +597,7 @@ class AzureServiceBusTopicDeleteOperator(BaseOperator):
         self,
         *,
         topic_name: str,
-        azure_service_bus_conn_id: str = 'azure_service_bus_default',
+        azure_service_bus_conn_id: str = "azure_service_bus_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -620,7 +605,7 @@ class AzureServiceBusTopicDeleteOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Delete topic in Service Bus namespace, by connecting to Service Bus Admin client"""
+        """Delete topic in Service Bus namespace, by connecting to Service Bus Admin client."""
         if self.topic_name is None:
             raise TypeError("Topic name cannot be None.")
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
