@@ -15,12 +15,12 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
+import csv
 import os
 from tempfile import TemporaryDirectory
-from typing import TYPE_CHECKING, Any, Optional, Sequence, Union
-
-import unicodecsv as csv
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.microsoft.azure.hooks.data_lake import AzureDataLakeHook
@@ -37,30 +37,20 @@ class OracleToAzureDataLakeOperator(BaseOperator):
 
 
     :param filename: file name to be used by the csv file.
-    :type filename: str
     :param azure_data_lake_conn_id: destination azure data lake connection.
-    :type azure_data_lake_conn_id: str
     :param azure_data_lake_path: destination path in azure data lake to put the file.
-    :type azure_data_lake_path: str
     :param oracle_conn_id: :ref:`Source Oracle connection <howto/connection:oracle>`.
-    :type oracle_conn_id: str
     :param sql: SQL query to execute against the Oracle database. (templated)
-    :type sql: str
     :param sql_params: Parameters to use in sql query. (templated)
-    :type sql_params: Optional[dict]
     :param delimiter: field delimiter in the file.
-    :type delimiter: str
     :param encoding: encoding type for the file.
-    :type encoding: str
     :param quotechar: Character to use in quoting.
-    :type quotechar: str
-    :param quoting: Quoting strategy. See unicodecsv quoting for more information.
-    :type quoting: str
+    :param quoting: Quoting strategy. See csv library for more information.
     """
 
-    template_fields: Sequence[str] = ('filename', 'sql', 'sql_params')
+    template_fields: Sequence[str] = ("filename", "sql", "sql_params")
     template_fields_renderers = {"sql_params": "py"}
-    ui_color = '#e08c8c'
+    ui_color = "#e08c8c"
 
     def __init__(
         self,
@@ -70,11 +60,11 @@ class OracleToAzureDataLakeOperator(BaseOperator):
         azure_data_lake_path: str,
         oracle_conn_id: str,
         sql: str,
-        sql_params: Optional[dict] = None,
+        sql_params: dict | None = None,
         delimiter: str = ",",
         encoding: str = "utf-8",
         quotechar: str = '"',
-        quoting: str = csv.QUOTE_MINIMAL,
+        quoting: int = csv.QUOTE_MINIMAL,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -91,12 +81,11 @@ class OracleToAzureDataLakeOperator(BaseOperator):
         self.quotechar = quotechar
         self.quoting = quoting
 
-    def _write_temp_file(self, cursor: Any, path_to_save: Union[str, bytes, int]) -> None:
-        with open(path_to_save, 'wb') as csvfile:
+    def _write_temp_file(self, cursor: Any, path_to_save: str | bytes | int) -> None:
+        with open(path_to_save, "w", encoding=self.encoding) as csvfile:
             csv_writer = csv.writer(
                 csvfile,
                 delimiter=self.delimiter,
-                encoding=self.encoding,
                 quotechar=self.quotechar,
                 quoting=self.quoting,
             )
@@ -104,7 +93,7 @@ class OracleToAzureDataLakeOperator(BaseOperator):
             csv_writer.writerows(cursor)
             csvfile.flush()
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         oracle_hook = OracleHook(oracle_conn_id=self.oracle_conn_id)
         azure_data_lake_hook = AzureDataLakeHook(azure_data_lake_conn_id=self.azure_data_lake_conn_id)
 
@@ -113,7 +102,7 @@ class OracleToAzureDataLakeOperator(BaseOperator):
         cursor = conn.cursor()  # type: ignore[attr-defined]
         cursor.execute(self.sql, self.sql_params)
 
-        with TemporaryDirectory(prefix='airflow_oracle_to_azure_op_') as temp:
+        with TemporaryDirectory(prefix="airflow_oracle_to_azure_op_") as temp:
             self._write_temp_file(cursor, os.path.join(temp, self.filename))
             self.log.info("Uploading local file to Azure Data Lake")
             azure_data_lake_hook.upload_file(
