@@ -28,9 +28,7 @@ from airflow.triggers.base import BaseTrigger, TriggerEvent
 
 
 class ADFPipelineRunStatusSensorTrigger(BaseTrigger):
-    """
-    ADFPipelineRunStatusSensorTrigger is fired as deferred class with params to run the
-    task in trigger worker, when ADF Pipeline is running
+    """Trigger with params to run the task when the ADF Pipeline is running.
 
     :param run_id: The pipeline run identifier.
     :param azure_data_factory_conn_id: The connection identifier for connecting to Azure Data Factory.
@@ -68,7 +66,7 @@ class ADFPipelineRunStatusSensorTrigger(BaseTrigger):
         )
 
     async def run(self) -> AsyncIterator[TriggerEvent]:
-        """Make async connection to Azure Data Factory, polls for the pipeline run status"""
+        """Make async connection to Azure Data Factory, polls for the pipeline run status."""
         hook = AzureDataFactoryAsyncHook(azure_data_factory_conn_id=self.azure_data_factory_conn_id)
         try:
             while True:
@@ -93,9 +91,9 @@ class ADFPipelineRunStatusSensorTrigger(BaseTrigger):
 
 
 class AzureDataFactoryTrigger(BaseTrigger):
-    """
-    AzureDataFactoryTrigger is triggered when Azure data factory pipeline job succeeded or failed.
-    When wait_for_termination is set to False it triggered immediately with success status
+    """Trigger when the Azure data factory pipeline job finishes.
+
+    When wait_for_termination is set to False, it triggers immediately with success status.
 
     :param run_id: Run id of a Azure data pipeline run job.
     :param azure_data_factory_conn_id: The connection identifier for connecting to Azure Data Factory.
@@ -141,7 +139,7 @@ class AzureDataFactoryTrigger(BaseTrigger):
         )
 
     async def run(self) -> AsyncIterator[TriggerEvent]:
-        """Make async connection to Azure Data Factory, polls for the pipeline run status"""
+        """Make async connection to Azure Data Factory, polls for the pipeline run status."""
         hook = AzureDataFactoryAsyncHook(azure_data_factory_conn_id=self.azure_data_factory_conn_id)
         try:
             pipeline_status = await hook.get_adf_pipeline_run_status(
